Python Client for Source Context
================================

|ga| |pypi| |versions|

This package contains generated Python types for `google.cloud.source_context_v1`

- `Client Library Documentation`_

.. |ga| image:: https://img.shields.io/badge/support-ga-gold.svg
   :target: https://github.com/googleapis/google-cloud-python/blob/main/README.rst#ga-support
.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-source-context.svg
   :target: https://pypi.org/project/google-cloud-source-context/
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-source-context.svg
   :target: https://pypi.org/project/google-cloud-source-context/
.. _Client Library Documentation: https://googleapis.dev/python/source/latest

Installation
------------

Install this library in a `virtualenv`_ using pip. `virtualenv`_ is a tool to
create isolated Python environments. The basic problem it addresses is one of
dependencies and versions, and indirectly permissions.

With `virtualenv`_, it's possible to install this library without needing system
install permissions, and without clashing with the installed system
dependencies.

.. _`virtualenv`: https://virtualenv.pypa.io/en/latest/


Mac/Linux
^^^^^^^^^

.. code-block:: console

    pip install virtualenv
    virtualenv <your-env>
    source <your-env>/bin/activate
    <your-env>/bin/pip install google-cloud-source-context


Windows
^^^^^^^

.. code-block:: console

    pip install virtualenv
    virtualenv <your-env>
    <your-env>\Scripts\activate
    <your-env>\Scripts\pip.exe install google-cloud-source-context
